@@ -73,6 +73,8 @@ $conf{'plugintimeout'} = 30;
 
 my $apprevision = '$Revision: 1.8.0 $';
 my $mac = '';
+my $root_dir = "/usr/share/eqos/";
+my $sqlite_dir = "/var/lib/sqlite/eqos/";
 my $halt = 0; # halt flag (stop service)
 my $sleeptime = 5; # time wait between each iteration of main loop
 my $proxyserver = ""; # http proxy used by SOAP
@@ -81,7 +83,6 @@ my $ceqos_server = 'eqos.orion.education.fr';
 my $soapuri = "http://$ceqos_server/ceqos"; # SOAP URI ( != url http !!)
 my $soapproxy = "http://$ceqos_server/eqos-collector/cgi-bin/ceqos-$ceqos_version.cgi"; # SOAP PROXY
 my $getdefaultproxy = "/etc/http_proxy"; # if can't locate proxy env vars, this file is used
-my $cmd_getmac = '/sbin/ifconfig eth0 | /bin/grep HWaddr | /bin/sed "s/^.*HWaddr \([^ ]*\).*$/\\1/"'; # get mac address with ifconfig method
 
 my $cmd_setdate = '/bin/date -u -s "1970-01-01 ? sec" > /dev/null 2>&1'; # command to modify the date (? replaced by timestamp)
 
@@ -98,15 +99,15 @@ my $globalname = "";
 
 
 my $pid_checker = -1;
-my $exec_checker = "./checker.pl"; # checker exe file
+my $exec_checker = $root_dir."checker.pl"; # checker exe file
 my $kill_checker = 15; # loop waited before killing checker
 
 my $pid_feedback = -1;
 my $kill_feedback = 15; # loop waited before killing feedback
 
 # SQLite
-my $sqlite_datafile = "/var/lib/sqlite/eqos/eqosd.sqlite";
-my $sqlite_structdumpfile = "sql/eqos_struct.sql";
+my $sqlite_datafile = $sqlite_dir."eqosd.sqlite";
+my $sqlite_structdumpfile = $root_dir."sql/eqos_struct.sql";
 
 my $feedback_max = 50; # max block sent to each SOAP packet
 
@@ -155,7 +156,7 @@ sub make_log {
 	my ($lvl, $str) = @_;
 	if ($lvl <= $debuglevel) {
 		my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday) = gmtime();
-		print WHITE . sprintf("%02d/%02d %02d:%02d:%02d", $mday, $mon, $hour, $min, $sec) . " [$globalname] $str" . RESET . "\n";
+		print WHITE . sprintf("%02d/%02d %02d:%02d:%02d", $mday, $mon+1, $hour, $min, $sec) . " [$globalname] $str" . RESET . "\n";
 	}
 }
 
@@ -206,7 +207,9 @@ sub signal_halt {
 
 # Return eth0 hardware address used for agent identification
 sub get_mac_address() {
-	my $sysfile = '/sys/class/net/eth0/address';
+	chomp(my $int = `ifconfig | egrep '^[^ ]' |  awk '{print \$1}'| head -1`);
+	&make_log(0, WHITE . "info: interface name " . BOLD MAGENTA . "\"$int\"");
+	my $sysfile = '/sys/class/net/'.$int.'/address';
 	my $mac = '';
 	if ( -e $sysfile ) {
 		open(SYSFILE,"<$sysfile");
